@@ -255,7 +255,7 @@ public class Terminal extends org.gnu.gtk.Widget {
 	 * 
 	 * @throws FileNotFoundException if the image doesn't exist.
 	 */
-	public void setBackgroudImage(String file) throws FileNotFoundException{
+	public void setBackgroundImage(String file) throws FileNotFoundException{
 		File f = new File(file);
 		if (f.exists())
 			vte_terminal_set_background_image_file(getHandle(), file);
@@ -317,7 +317,7 @@ public class Terminal extends org.gnu.gtk.Widget {
 	 * is set and when the terminal is not transparent.
 	 * @param color
 	 */
-	public void setBackgroudColor(Color color) {
+	public void setBackgroundColor(Color color) {
 		vte_terminal_set_color_background(getHandle(), color.getHandle());
 	}	
 
